==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1beta1ExternalDocumentationFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1beta1ExternalDocumentationFluentImpl<A extends V1beta1ExternalDocumentationFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1beta1ExternalDocumentationFluent<A>{

    private String description;
    private String url;

    public V1beta1ExternalDocumentationFluentImpl(){
    }
    public V1beta1ExternalDocumentationFluentImpl(V1beta1ExternalDocumentation instance){
            this.withDescription(instance.getDescription());

            this.withUrl(instance.getUrl());

    }

    public String getDescription(){
            return this.description;
    }

    public A withDescription(String description){
            this.description=description; return (A) this;
    }

    public Boolean hasDescription(){
            return this.description != null;
    }

    public String getUrl(){
            return this.url;
    }

    public A withUrl(String url){
            this.url=url; return (A) this;
    }

    public Boolean hasUrl(){
            return this.url != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1beta1ExternalDocumentationFluentImpl that = (V1beta1ExternalDocumentationFluentImpl) o;
            if (description != null ? !description.equals(that.description) :that.description != null) return false;
            if (url != null ? !url.equals(that.url) :that.url != null) return false;
            return true;
    }




}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1beta1ExternalDocumentationFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1beta1ExternalDocumentationFluentImpl<A extends V1beta1ExternalDocumentationFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1beta1ExternalDocumentationFluent<A>{

    private String description;
    private String url;

    public V1beta1ExternalDocumentationFluentImpl(){
    }
    public V1beta1ExternalDocumentationFluentImpl(V1beta1ExternalDocumentation instance){
            this.withDescription(instance.getDescription());

            this.withUrl(instance.getUrl());

    }

    public String getDescription(){
            return this.description;
    }

    public A withDescription(String description){
            this.description=description; return (A) this;
    }

    public Boolean hasDescription(){
            return this.description != null;
    }

    public A withNewDescription(String arg1){
            return (A)withDescription(new String(arg1));
    }

    public A withNewDescription(StringBuilder arg1){
            return (A)withDescription(new String(arg1));
    }

    public A withNewDescription(StringBuffer arg1){
            return (A)withDescription(new String(arg1));
    }

    public String getUrl(){
            return this.url;
    }

    public A withUrl(String url){
            this.url=url; return (A) this;
    }

    public Boolean hasUrl(){
            return this.url != null;
    }

    public A withNewUrl(String arg1){
            return (A)withUrl(new String(arg1));
    }

    public A withNewUrl(StringBuilder arg1){
            return (A)withUrl(new String(arg1));
    }

    public A withNewUrl(StringBuffer arg1){
            return (A)withUrl(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1beta1ExternalDocumentationFluentImpl that = (V1beta1ExternalDocumentationFluentImpl) o;
            if (description != null ? !description.equals(that.description) :that.description != null) return false;
            if (url != null ? !url.equals(that.url) :that.url != null) return false;
            return true;
    }




}
